@@ -89,8 +89,8 @@ _vzctl()
 		--diskspace --diskinodes --quotatime --quotaugidlimit \
 		--capability --devnodes --devices --applyconfig \
 		--name --ioprio --setmode --meminfo --bootorder --features \
-		--reset_ub"
-	local vzctl_start_opts="--wait --force"
+		--reset_ub --stop-timeout"
+	local vzctl_start_opts="--wait --force --skip-fsck"
 	local vzctl_stop_opts="--fast --skip-umount"
 	local vzctl_restart_opts="$vzctl_start_opts $vzctl_stop_opts"
 	local vzctl_snapshot_create_opts="--id --name --description \
@@ -155,7 +155,7 @@ _vzctl()
 				local vztmpl=`grep ^TEMPLATE /etc/vz/vz.conf | cut -d "=" -f 2`
 				COMPREPLY=( $( compgen -W "$(command ls $vztmpl/cache/*.tar{,.gz,.xz,.bz2} 2>/dev/null |
 						    sed -e "s#^$vztmpl/cache/##" -e 's#\.tar\.*[gbxz2]*$##';
-						    /usr/libexec/vzctl/scripts/vps-download --list)" -- $cur ) )
+						    /usr/sbin/vztmpl-dl --list)" -- $cur ) )
 
 				;;
 			--onboot|--disabled|--diskquota)
